@@ -84,7 +84,7 @@ class GtfFeatureReader:
 
   public:
     bool hasMoreFeature() const { return nextLine_ != ""; }
-    const BasicSequenceFeature nextFeature() throw (Exception);
+    const BasicSequenceFeature nextFeature();
 
     void getAllFeatures(SequenceFeatureSet& features) {
       while (hasMoreFeature()) {
