@@ -154,7 +154,7 @@ class AlignmentFilterMafIterator:
 
 
   public:
-    MafBlock* nextRemovedBlock() throw (Exception) {
+    MafBlock* nextRemovedBlock() {
       if (trashBuffer_.size() == 0) return 0;
       MafBlock* block = trashBuffer_.front();
       trashBuffer_.pop_front();
@@ -162,7 +162,7 @@ class AlignmentFilterMafIterator:
     }
 
   private:
-    MafBlock* analyseCurrentBlock_() throw (Exception);
+    MafBlock* analyseCurrentBlock_();
 };
 
 /**
@@ -251,7 +251,7 @@ class AlignmentFilter2MafIterator:
     {}
 
   public:
-    MafBlock* nextRemovedBlock() throw (Exception) {
+    MafBlock* nextRemovedBlock() {
       if (trashBuffer_.size() == 0) return 0;
       MafBlock* block = trashBuffer_.front();
       trashBuffer_.pop_front();
@@ -259,7 +259,7 @@ class AlignmentFilter2MafIterator:
     }
 
   private:
-    MafBlock* analyseCurrentBlock_() throw (Exception);
+    MafBlock* analyseCurrentBlock_();
 
 };
 
