@@ -92,7 +92,7 @@ class ConcatenateMafIterator:
     }
 
   private:
-    MafBlock* analyseCurrentBlock_() throw (Exception);
+    MafBlock* analyseCurrentBlock_();
 
 };
 
