@@ -47,7 +47,7 @@ using namespace bpp;
 
 using namespace std;
 
-MafBlock* EntropyFilterMafIterator::analyseCurrentBlock_() throw (Exception)
+MafBlock* EntropyFilterMafIterator::analyseCurrentBlock_()
 {
   if (blockBuffer_.size() == 0) {
     //Else there is no more block in the buffer, we need to parse more:
