@@ -97,7 +97,7 @@ class FeatureExtractorMafIterator:
     }
 
   private:
-    MafBlock* analyseCurrentBlock_() throw (Exception);
+    MafBlock* analyseCurrentBlock_();
 
 };
 
