@@ -98,7 +98,7 @@ class OrphanSequenceFilterMafIterator:
     }
 
   private:
-    MafBlock* analyseCurrentBlock_() throw (Exception);
+    MafBlock* analyseCurrentBlock_();
 
 };
 
