@@ -98,7 +98,7 @@ class SequenceStatisticsMafIterator:
     const std::vector<std::string>& getResultsColumnNames() const { return names_; }
 
   private:
-    MafBlock* analyseCurrentBlock_() throw (Exception);
+    MafBlock* analyseCurrentBlock_();
 
 };
 
