@@ -131,6 +131,9 @@ void VcfOutputMafIterator::writeBlock_(std::ostream& out, const MafBlock& block)
         snps[x] = 0;
       }
     }
+    if (ac == "" && outputAll_) {
+      ac = TextTools::toString(counts[ref]);
+    }
     if (ac != "") {
       out << chr << "\t" << (offset + walker.getSequencePosition(i) + 1) << "\t.\t" << chars[refSeq[i]] << "\t" << alt << "\t.\t" << filter << "\tAC=" << ac;
       //Write genotpyes:
